@@ -2,7 +2,7 @@
  *
  * Create a packet from a format string and arguments.
  *
- * $Id: format.h,v 1.26 1999/11/21 22:36:04 nisse Exp $ */
+ * $Id: format.h,v 1.27 1999/12/12 19:33:59 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -100,9 +100,4 @@ int lsh_string_eq_l(const struct lsh_string *a, UINT32 length, const UINT8 *b);
 int lsh_string_prefixp(const struct lsh_string *prefix,
 		       const struct lsh_string *s);
 
-#if 0
-int lsh_string_cmp(const struct lsh_string *a, const struct lsh_string *b);
-int lsh_string_cmp_l(const struct lsh_string *a, UINT32 length, const UINT8 *b);
-#endif
-
 #endif /* LSH_FORMAT_H_INCLUDED */
